==> open-cluster-management-observability-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta1/ObservabilityAddonBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ObservabilityAddonBuilder extends ObservabilityAddonFluentImpl<ObservabilityAddonBuilder> implements VisitableBuilder<ObservabilityAddon,ObservabilityAddonBuilder>{
  public ObservabilityAddonBuilder() {
    this(false);
  }
  public ObservabilityAddonBuilder(Boolean validationEnabled) {
    this(new ObservabilityAddon(), validationEnabled);
  }
  public ObservabilityAddonBuilder(ObservabilityAddonFluent<?> fluent) {
    this(fluent, false);
  }
  public ObservabilityAddonBuilder(ObservabilityAddonFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ObservabilityAddon(), validationEnabled);
  }
  public ObservabilityAddonBuilder(ObservabilityAddonFluent<?> fluent,ObservabilityAddon instance) {
    this(fluent, instance, false);
  }
  public ObservabilityAddonBuilder(ObservabilityAddonFluent<?> fluent,ObservabilityAddon instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ObservabilityAddonBuilder(ObservabilityAddon instance) {
    this(instance,false);
  }
  public ObservabilityAddonBuilder(ObservabilityAddon instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  ObservabilityAddonFluent<?> fluent;
  Boolean validationEnabled;
  public ObservabilityAddon build() {
    ObservabilityAddon buildable = new ObservabilityAddon(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}

==> open-cluster-management-observability-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta1/ObservabilityAddonBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ObservabilityAddonBuilder extends ObservabilityAddonFluent<ObservabilityAddonBuilder> implements VisitableBuilder<ObservabilityAddon,ObservabilityAddonBuilder>{
  public ObservabilityAddonBuilder() {
    this(false);
  }
  public ObservabilityAddonBuilder(Boolean validationEnabled) {
    this(new ObservabilityAddon(), validationEnabled);
  }
  public ObservabilityAddonBuilder(ObservabilityAddonFluent<?> fluent) {
    this(fluent, false);
  }
  public ObservabilityAddonBuilder(ObservabilityAddonFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ObservabilityAddon(), validationEnabled);
  }
  public ObservabilityAddonBuilder(ObservabilityAddonFluent<?> fluent,ObservabilityAddon instance) {
    this(fluent, instance, false);
  }
  public ObservabilityAddonBuilder(ObservabilityAddonFluent<?> fluent,ObservabilityAddon instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ObservabilityAddon());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ObservabilityAddonBuilder(ObservabilityAddon instance) {
    this(instance,false);
  }
  public ObservabilityAddonBuilder(ObservabilityAddon instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ObservabilityAddon());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  ObservabilityAddonFluent<?> fluent;
  Boolean validationEnabled;
  public ObservabilityAddon build() {
    ObservabilityAddon buildable = new ObservabilityAddon(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    return buildable;
  }
  
}
